@@ -1,12 +1,11 @@
 package com.openexchange.util.custom.base;
 
-import javax.annotation.ParametersAreNonnullByDefault;
+
 import com.google.common.collect.ImmutableSet;
 
 /**
  * Successful result of a {@linkplain StringInterpolator#interpolate(CharSequence, String, String) string interpolation}.
  */
-@ParametersAreNonnullByDefault
 public final class StringInterpolation {
     
     private final String result;
